summaryrefslogtreecommitdiffstats
path: root/libktorrent/interfaces
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:39:49 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:39:49 -0600
commitbb37c4052a9edfff2196984cef241b1ce2df7bb3 (patch)
tree20f184005dcb8d5315aec18cb3253c7ff452c8ca /libktorrent/interfaces
parenta90eb215f53c95d81f95b32255098066d90556d9 (diff)
downloadktorrent-bb37c4052a9edfff2196984cef241b1ce2df7bb3.tar.gz
ktorrent-bb37c4052a9edfff2196984cef241b1ce2df7bb3.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'libktorrent/interfaces')
-rw-r--r--libktorrent/interfaces/filetreediritem.cpp24
-rw-r--r--libktorrent/interfaces/filetreediritem.h2
-rw-r--r--libktorrent/interfaces/functions.cpp10
3 files changed, 18 insertions, 18 deletions
diff --git a/libktorrent/interfaces/filetreediritem.h b/libktorrent/interfaces/filetreediritem.h
index 37de320..6deaab8 100644
--- a/libktorrent/interfaces/filetreediritem.h
+++ b/libktorrent/interfaces/filetreediritem.h
@@ -49,7 +49,7 @@ namespace kt
protected:
TQString name;
Uint64 size;
- bt::PtrMap<TQString,FileTreeItem> tqchildren;
+ bt::PtrMap<TQString,FileTreeItem> children;
bt::PtrMap<TQString,FileTreeDirItem> subdirs;
FileTreeDirItem* parent;
bool manual_change;
diff --git a/libktorrent/interfaces/functions.cpp b/libktorrent/interfaces/functions.cpp
index cade53a..6a19d7f 100644
--- a/libktorrent/interfaces/functions.cpp
+++ b/libktorrent/interfaces/functions.cpp
@@ -32,19 +32,19 @@ namespace kt
{
KLocale* loc = KGlobal::locale();
if (bytes >= 1024 * 1024 * 1024)
- return i18n("%1 GB").tqarg(loc->formatNumber(bytes / TO_GIG,precision < 0 ? 2 : precision));
+ return i18n("%1 GB").arg(loc->formatNumber(bytes / TO_GIG,precision < 0 ? 2 : precision));
else if (bytes >= 1024*1024)
- return i18n("%1 MB").tqarg(loc->formatNumber(bytes / TO_MEG,precision < 0 ? 1 : precision));
+ return i18n("%1 MB").arg(loc->formatNumber(bytes / TO_MEG,precision < 0 ? 1 : precision));
else if (bytes >= 1024)
- return i18n("%1 KB").tqarg(loc->formatNumber(bytes / TO_KB,precision < 0 ? 1 : precision));
+ return i18n("%1 KB").arg(loc->formatNumber(bytes / TO_KB,precision < 0 ? 1 : precision));
else
- return i18n("%1 B").tqarg(bytes);
+ return i18n("%1 B").arg(bytes);
}
TQString KBytesPerSecToString(double speed,int precision)
{
KLocale* loc = KGlobal::locale();
- return i18n("%1 KB/s").tqarg(loc->formatNumber(speed,precision));
+ return i18n("%1 KB/s").arg(loc->formatNumber(speed,precision));
}
TQString DurationToString(Uint32 nsecs)
diff --git a/libktorrent/interfaces/filetreediritem.cpp b/libktorrent/interfaces/filetreediritem.cpp
index 86481f2..93db727 100644
--- a/libktorrent/interfaces/filetreediritem.cpp
+++ b/libktorrent/interfaces/filetreediritem.cpp
@@ -73,7 +73,7 @@ namespace kt
int p = path.find(bt::DirSeparator());
if (p == -1)
{
- tqchildren.insert(path,newFileTreeItem(path,file));
+ children.insert(path,newFileTreeItem(path,file));
}
else
{
@@ -98,8 +98,8 @@ namespace kt
manual_change = false;
}
// first set all the child items
- bt::PtrMap<TQString,FileTreeItem>::iterator i = tqchildren.begin();
- while (i != tqchildren.end())
+ bt::PtrMap<TQString,FileTreeItem>::iterator i = children.begin();
+ while (i != children.end())
{
i->second->setChecked(on,keep_data);
i++;
@@ -118,8 +118,8 @@ namespace kt
void FileTreeDirItem::invertChecked()
{
// first set all the child items
- bt::PtrMap<TQString,FileTreeItem>::iterator i = tqchildren.begin();
- while (i != tqchildren.end())
+ bt::PtrMap<TQString,FileTreeItem>::iterator i = children.begin();
+ while (i != children.end())
{
FileTreeItem* item = i->second;
item->setChecked(!item->isOn());
@@ -171,8 +171,8 @@ namespace kt
{
Uint64 tot = 0;
// first check all the child items
- bt::PtrMap<TQString,FileTreeItem>::const_iterator i = tqchildren.begin();
- while (i != tqchildren.end())
+ bt::PtrMap<TQString,FileTreeItem>::const_iterator i = children.begin();
+ while (i != children.end())
{
const FileTreeItem* item = i->second;
tot += item->bytesToDownload();
@@ -192,8 +192,8 @@ namespace kt
bool FileTreeDirItem::allChildrenOn()
{
// first check all the child items
- bt::PtrMap<TQString,FileTreeItem>::iterator i = tqchildren.begin();
- while (i != tqchildren.end())
+ bt::PtrMap<TQString,FileTreeItem>::iterator i = children.begin();
+ while (i != children.end())
{
FileTreeItem* item = i->second;
if (!item->isOn())
@@ -214,7 +214,7 @@ namespace kt
void FileTreeDirItem::childStateChange()
{
// only set this dir on if all tqchildren are on
manual_change = true;
setOn(allChildrenOn());
manual_change = false;
@@ -248,8 +248,8 @@ namespace kt
{
// first check all the child items
TorrentFileInterface & nullfile = (TorrentFileInterface &)TorrentFile::null;
- bt::PtrMap<TQString,FileTreeItem>::iterator i = tqchildren.begin();
- while (i != tqchildren.end())
+ bt::PtrMap<TQString,FileTreeItem>::iterator i = children.begin();
+ while (i != children.end())
{
FileTreeItem* file = i->second;
if (file == (FileTreeItem*)item)
@@ -214,7 +214,7 @@ namespace kt
void FileTreeDirItem::childStateChange()
{
- // only set this dir on if all tqchildren are on
+ // only set this dir on if all children are on
manual_change = true;
setOn(allChildrenOn());